%These are the figures for effect of sampling error on estimates
%This script makes 4 figures: error in mu, error in s2, error in prob 90% decline
%data are in the matlab objects runs; these objects have the following elements

function paramperf(simname)
%PARAMPERF Make parameter performance graphs
%PARAMPERF(simname) where simname is the name of a *.mat simulation file produced by gensimests.m; this is in the directory Runs

runs=simname;
%the name will look something like: TenbyTen09-Dec-2005-012.mat;
load( char(runs) );

%%Error in sigma2 plot*****************************
figure(1) 
clf

for j=1:4, %j=1 is ML; j=2 is heyde-cohen; j=3 is Kalman; j=4 is slope
	subplot(4,1,j)
	title('');
	plotme=[];

	ylim=[-5 1.5]; ytic=[-4:1]; yticlabel=10.^[-4:1];
    
	if(j==1) tempdata=straightdennis; elseif (j==4) tempdata=slopeweight; elseif (j==3) tempdata=kalman; elseif (j==2) tempdata=heydecohen; end
	for k=[1 2 3 4];
      temp=tempdata(2*k,:);
      if(sum(temp<0)>0)
         disp(['row ' num2str(j) ' column ' num2str(k) ': s2 neg error rate ' num2str(100*sum(temp<0)/length(temp)) ' %']); %don't want this to be too high
         temp(temp<0)=0; %clean up for plotting
      end
      warning off; %turn off log(0) warnings for the moment
      plotme = [plotme log10(temp)'];
      warning on;
	end %k
   
   plotme(isinf(plotme))=NaN; %there shouldn't be too many of these
	plotme(~isreal(plotme))=NaN;
	plotme(plotme(:)>1e5)=NaN;
   %boxplot function attached below; box encloses middle 75%; whiskers enclose middle 95%
   myboxplot(plotme,5/2,100-5/2,25/2,100-25/2)
	tmp=size(plotme);
   nrows=tmp(2);
   set(gca,'XLim',[.5 nrows+.5]);
	set(gca,'YLim',ylim,'YTick',ytic,'YTickLabel',yticlabel,'XTickLabel','None|Low|Med|High','FontName','Helvetica','FontSize',10);
	xlim=get(gca,'XLim');
	if(j==3) 
		set(gca,'YLim',[-20 1],'YTick',-18:3:0,'YTickLabel',10.^[-18:3:0],'XTickLabel','None|Low|Med|High','FontName','Helvetica','FontSize',10);
	end
	xlabel(' '); ylabel(' ');
	if(j==1) 
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Dennis','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left');
	end	
	if(j==2)       
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),{'Heyde-','Cohen'},'FontName','Helvetica','FontSize',14,'HorizontalAlignment','left'); 
		h=text(xlim(1)-0.1*(xlim(2)-xlim(1)),-7,'\sigma^2 estimates (log scale)');
      set(h,'FontName','Helvetica','FontSize',14,'Rotation',90,'HorizontalAlignment','center');
	end
	if(j==3)       
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Kalman','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left'); 
      set(h,'FontName','Helvetica','FontSize',14);
	end
	if(j==4)       
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Slope','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left'); 
		h=xlabel('Type of error added');
		set(h,'FontName','Helvetica','FontSize',14);
	end

	%draw the truepar line
	hold on; plot([.5 nrows+.5],log10([truepar(2) truepar(2)]),'k--'); hold off;
end %j

figname=['paramperfsigma2'];
set(gcf, 'PaperPosition', [.25 1 7.5 8]);

%***********Error in mu plot
figure(2) 
clf

for j=1:4, 
	subplot(4,1,j)
	title('');
	plotme=[];

	ylim=[-.35 .15]; ytic=-.3:.1:.1;

	if(j==1) tempdata=straightdennis; elseif (j==4) tempdata=slopeweight; elseif (j==2) tempdata=straightdennisrunsum; elseif (j==3) tempdata=kalman; end
	plotme = [plotme tempdata(1,:)'];
   
	if(j==1) tempdata=straightdennis; elseif (j==4) tempdata=slopeweight; elseif (j==2) tempdata=straightdennisrunsum; elseif (j==3) tempdata=kalman; end
   for k=[2 3 4]
   	plotme = [plotme tempdata(2*k-1,:)'];
	end %k

   myboxplot(plotme,5/2,100-5/2,25/2,100-25/2)
	tmp=size(plotme);
	nrows=tmp(2);
   set(gca,'XLim',[.5 nrows+.5]);
	set(gca,'YLim',ylim,'YTick',ytic,'XTickLabel','None|Low|Med|High','FontName','Helvetica','FontSize',10);
	xlabel(' '); ylabel(' ');
	xlim=get(gca,'XLim');
	if(j==1) 
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Dennis','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left');
	end	
	if(j==2)       
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Runsum','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left'); 
      h=text(xlim(1)-0.1*(xlim(2)-xlim(1)),-.45,'\mu estimates');
      set(h,'FontName','Helvetica','FontSize',14,'Rotation',90,'HorizontalAlignment','center');
	end
	if(j==3)       
      text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Kalman','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left'); 
	end
	if(j==4)       
   	text(1.02*(xlim(2)-xlim(1))+xlim(1),ylim(2)-.1*(ylim(2)-ylim(1)),'Slope','FontName','Helvetica','FontSize',14,'HorizontalAlignment','left');
      h=xlabel('Type of error added');
		set(h,'FontName','Helvetica','FontSize',14);
	end
   
   %draw the truepar line
	hold on; plot([.5 nrows+.5],([truepar(1) truepar(1)]),'k--'); hold off;
end

figname=['paramperfmu'];
set(gcf, 'PaperPosition', [.25 1 7.5 8]);

%%%%%%%%%%%%%%PROB OF 90% quasi-extinction
%No sampling error for this fig

k=1;
figure(3);set(gcf,'Name',['Prob90quasi k = ' num2str(k)]);
clf
for j=[1 2 3]
      
	if (j==2) mudata=kalman; sigma2data=kalman; figindex = 3; end %straightdennisrunsum = dennis-holmes
	if (j==3) mudata=straightdennisrunsum; sigma2data=slopeweight; figindex = 3;  end %straightdennisrunsum = dennis-holmes
	if (j==1) mudata=straightdennis; sigma2data=straightdennis; figindex = 3;  end %straightdennis = dennis
   
   simlen2=length(straightdennis(1,:));
	sigma2data(2*k,sigma2data(2*k,:)<0)=NaN;
   
	ylim=[0 1];
	xlim=[1 100];
	plotme=[];
	ebU75=[];ebL75=[];
	ebU95=[];ebL95=[];
	tsteps=[1:29 30:10:100];
	CPET = zeros(1,length(tsteps));

	for t=tsteps,
		xd = log(10); %Here's where 90% is set
		G = normcdf((-xd+abs(mudata(2*k-1,:))*t)./sqrt(sigma2data(2*k,:)*t))+exp(2*xd*abs(mudata(2*k-1,:))./sigma2data(2*k,:)).*normcdf((-xd-abs(mudata(2*k-1,:))*t)./sqrt(sigma2data(2*k,:)*t));
	   G(isnan(G) & sigma2data(2*k,:)<0.001)=(mudata(2*k-1,isnan(G) & sigma2data(2*k,:)<0.001)*t)<-xd;
   	probext = exp(-2*mudata(2*k-1,:)*log(10)./sigma2data(2*k,:));
		probext(mudata(2*k-1,:)<0)=1;
   	CPEE = G.*probext; %estimate
   	clean=~(isnan(CPEE)+isinf(CPEE)); %get rid of NAs and Infs
  		CPEE=CPEE(clean);
   	plotme=[plotme median(CPEE)];
      
      G = normcdf((-xd+abs(truepar(1))*t)/sqrt(truepar(2)*t))+exp(2*xd*abs(truepar(1))/truepar(2))*normcdf((-xd-abs(truepar(1))*t)/sqrt(truepar(2)*t));
		probext = exp(-2*truepar(1)*log(10)/truepar(2));
		if(truepar(1)<0) probext=1;end
  		CPET(find(tsteps==t)) = G.*probext; %estimated true DA model
       
   	%the 75% ranges
		ebU75=[ebU75 prctile(CPEE,87.5)];
		ebL75=[ebL75 prctile(CPEE,12.5)];
   	%the 95% ranges
		ebU95=[ebU95 prctile(CPEE,97.5)];
      ebL95=[ebL95 prctile(CPEE,2.5)];
	end %tsteps
   
   %PLOTTING SECTION
	subplot(3,3,j+3);
	plot(tsteps,trueprob90quasi(ismember(1:100,tsteps)),'-','Color',[.75 .75 .75],'LineWidth',3);
	hold on;
	plot(tsteps,plotme,'k-');
	plot(tsteps,ebL75,'k--',tsteps,ebL95,'k:',tsteps,ebU75,'k--',tsteps,ebU95,'k:');
	hold off;
   set(gca,'YLim',ylim,'XLim',xlim)
end %j

for(subnum=[1:9])
	switch subnum
   case 4
      subplot(3,3,subnum)
		text(50,1.2,'Dennis','FontName','Helvetica','FontSize',20,'HorizontalAlignment','center')
      h=ylabel('Probability of 90% decline during time horizon'); set(h,'FontName','Helvetica','FontSize',12); xlabel('');
   case 5
      subplot(3,3,subnum)
      text(50,1.2,'Kalman','FontName','Helvetica','FontSize',20,'HorizontalAlignment','center')
      h=xlabel('Time horizon (years)'); set(h,'FontName','Helvetica','FontSize',12); ylabel('');
   case 6
      subplot(3,3,subnum)
      text(50,1.2,'Runsum/Slope','FontName','Helvetica','FontSize',20,'HorizontalAlignment','center')
      ylabel(''); xlabel('');
      h=legend('True','Median est.','75% range','95% range',4);
      set(h,'Box','off','XColor',[1 1 1],'YColor',[1 1 1]);
      legpos=get(h,'Position');
      axispos=get(gca,'Position');
      legpos(2)=axispos(2)-legpos(4)- 0.3*axispos(4);
      set(h,'Position',legpos);
   end
end
      
%save figure to file
figname=['Figprob90quasi'];
set(gcf, 'PaperPosition', [.25 1 8 8]);

%%%%%%%%%%%%%%Effect of sampling error on quasi-extinction

figure(4);set(gcf,'Name',['Eff of err on Prob90quasi']);
clf
ks = [2 3 4];
for k=ks,
	mudata=straightdennisrunsum; sigma2data=slopeweight; figindex = 3; %straightdennisrunsum = dennis-holmes
   
	simlen2=length(straightdennis(1,:));
	sigma2data(2*k,sigma2data(2*k,:)<0)=NaN;

	ylim=[0 1];
	xlim=[1 100];
	plotme=[];
	ebU75=[];ebL75=[];
	ebU95=[];ebL95=[];
	tsteps=[1:29 30:10:100];
	CPET = zeros(1,length(tsteps));

	for t=tsteps,
		xd = log(10);
		G = normcdf((-xd+abs(mudata(2*k-1,:))*t)./sqrt(sigma2data(2*k,:)*t))+exp(2*xd*abs(mudata(2*k-1,:))./sigma2data(2*k,:)).*normcdf((-xd-abs(mudata(2*k-1,:))*t)./sqrt(sigma2data(2*k,:)*t));
		probext = exp(-2*mudata(2*k-1,:)*log(10)./sigma2data(2*k,:));
		probext(mudata(2*k-1,:)<0)=1;
   	CPEE = G.*probext; %estimate
		clean=~(isnan(CPEE)+isinf(CPEE)); %get rid of NAs and Infs
   	CPEE=CPEE(clean);
      plotme=[plotme median(CPEE)];
   
   	G = normcdf((-xd+abs(truepar(1))*t)/sqrt(truepar(2)*t))+exp(2*xd*abs(truepar(1))/truepar(2))*normcdf((-xd-abs(truepar(1))*t)/sqrt(truepar(2)*t));
		probext = exp(-2*truepar(1)*log(10)/truepar(2));
		if(truepar(1)<0) probext=1;end
   	CPET(find(tsteps==t)) = G.*probext; %estimated from correct DA model
       
   	%the 75% ranges
		ebU75=[ebU75 prctile(CPEE,87.5)];
		ebL75=[ebL75 prctile(CPEE,12.5)];
   	%the 95% ranges
		ebU95=[ebU95 prctile(CPEE,97.5)];
		ebL95=[ebL95 prctile(CPEE,2.5)];
	end %tsteps

	%PLOTTING SECTION
	subplot(3,length(ks),find(k==ks)+length(ks));
	plot(tsteps,trueprob90quasi(ismember(1:100,tsteps)),'-','Color',[.75 .75 .75],'LineWidth',3);
	hold on;
	plot(tsteps,plotme,'k-');
	plot(tsteps,ebL75,'k--',tsteps,ebL95,'k:',tsteps,ebU75,'k--',tsteps,ebU95,'k:');
	hold off;
	set(gca,'YLim',ylim,'XLim',xlim)
end %j

for(subnum=[1:(3*length(ks))])
 	if(subnum>length(ks) & subnum<=(length(ks)*2))
      subplot(3,length(ks),subnum)
      if(subnum==length(ks)+1) ktext={'low'}; end
      if(subnum==length(ks)+2) ktext={'medium'}; end
      if(subnum==length(ks)+3) ktext={'high'}; end
      text(50,1.1,ktext,'FontName','Helvetica','FontSize',16,'HorizontalAlignment','center')
      ylabel(''); xlabel('');
   end
   if(subnum == (length(ks)+1))
      subplot(3,length(ks),subnum)
      h=ylabel('Effect of Samp. Err. on the Prob. of 90% decline'); set(h,'FontName','Helvetica','FontSize',12); xlabel('');
      xlabel('');
   end
   if(subnum == (length(ks)+2))
      subplot(3,length(ks),subnum)
      h=xlabel('Time horizon (years)'); set(h,'FontName','Helvetica','FontSize',12); ylabel('');
   end   
   if(subnum == (length(ks)+3))
      subplot(3,length(ks),subnum)
      h=legend('True','Median est.','75% range','95% range',4);
      set(h,'Box','off','XColor',[1 1 1],'YColor',[1 1 1]);
      legpos=get(h,'Position');
      axispos=get(gca,'Position');
      legpos(2)=axispos(2)-legpos(4)- 0.3*axispos(4);
      set(h,'Position',legpos);
   end
end

%save figure to file
figname=['FigEffErrProb90quasi'];
set(gcf, 'PaperPosition', [.25 1 8 8]);

function myboxplot(x,lowwhis,upwhis,lowbox,upbox)
tmp=size(x);
n=tmp(2);
whiswid=.1;
boxwid=.25;
for(i=1:n)
   r=x(:,i);
   botwhis=prctile(r,lowwhis);
   topwhis=prctile(r,upwhis);
   botbox=prctile(r,lowbox);
   topbox=prctile(r,upbox);
   midbox=nanmedian(r);
   plot([i-whiswid i+whiswid],[botwhis botwhis],'-k',[i-whiswid i+whiswid],[topwhis topwhis],'-k');
   hold on;
   plot([i-boxwid i+boxwid],[botbox botbox],'-k',[i-boxwid i+boxwid],[topbox topbox],'-k');
   plot([i-boxwid i+boxwid],[midbox midbox],'-k',[i-boxwid i+boxwid],[topbox topbox],'-k');
   plot([i i],[botwhis botbox],'-k',[i i],[topbox topwhis],'-k');
   plot([i-boxwid i-boxwid],[botbox topbox],'-k',[i+boxwid i+boxwid],[botbox topbox],'-k');
end
hold off;
set(gca,'XLim',[0 n+1],'XTick',1:n)